@@ -1,7 +1,7 @@
 from django.contrib import admin
 from django.urls import reverse
 
-from django_bootmin.base import AdminView
+from simpel.simpel_admin.base import AdminView
 
 
 class AdminProfileUpdateView(AdminView):
