@@ -7,15 +7,16 @@ from django.contrib.admin.utils import quote
 from django.contrib.auth.models import AbstractUser
 from django.contrib.contenttypes.fields import GenericForeignKey, GenericRelation
 from django.contrib.contenttypes.models import ContentType
-from django.core.validators import MaxValueValidator, MinValueValidator
-from django.db import models  # NOQA
-from django.urls import NoReverseMatch, reverse
+from django.db import models
+from django.urls import NoReverseMatch
 from django.utils import timezone
 from django.utils.text import get_text_list
-from django.utils.translation import get_language, gettext_lazy as _
+from django.utils.translation import get_language
+from django.utils.translation import gettext_lazy as _
 
 from simpel.simpel_core import utils
 from simpel.simpel_core.permissions import user_can_edit_setting
+from simpel.utils import reverse
 
 from .managers import ActivityManager, NotificationQuerySet, UserManager
 from .utils import get_gravatar_url, id2slug, upload_avatar_to
@@ -583,6 +584,7 @@ class Activity(models.Model):
                 return reverse(
                     admin_urlname(self.action_object._meta, "change"),
                     args=(quote(self.action_object),),
+                    host="admin",
                 )
             except NoReverseMatch:
                 pass
@@ -743,39 +745,3 @@ class Notification(models.Model):
         if not self.unread:
             self.unread = True
             self.save()
-
-
-class Flag(models.Model):
-    created_at = models.DateTimeField(
-        default=timezone.now,
-        editable=False,
-    )
-    user = models.ForeignKey(
-        User,
-        limit_choices_to={"is_partial": True},
-        related_name="favorite_products",
-        on_delete=models.CASCADE,
-        verbose_name=_("Item"),
-    )
-    flagged_object_type = models.ForeignKey(
-        ContentType,
-        related_name="flags",
-        on_delete=models.CASCADE,
-        help_text=_("Flagged object type"),
-    )
-    flagged_object_id = models.IntegerField(
-        help_text=_("Flagged object primary key."),
-    )
-    flagged_object = GenericForeignKey(
-        "flagged_object_type",
-        "flagged_object_id",
-    )
-    value = models.IntegerField(
-        validators=[
-            MinValueValidator(1),
-            MaxValueValidator(10),
-        ]
-    )
-
-    def __str__(self):
-        return "%s flagged %s" % (self.user, self.flagged_object)
