@@ -1,6 +1,7 @@
-import factory as fc
 from django.contrib.auth import get_user_model
 from django.utils import timezone
+
+import factory as fc
 from PIL import Image
 
 from ..models import Profile
@@ -30,8 +31,6 @@ class UserFactory(fc.django.DjangoModelFactory):
 
 class ProfileFactory(fc.django.DjangoModelFactory):
     user = fc.SubFactory(UserFactory)
-    gender = fc.Iterator([Profile.MALE, Profile.FEMALE])
-    full_name = fc.LazyAttribute(lambda a: "{} {}".format(a.user.first_name, a.user.last_name).title())
 
     class Meta:
         model = Profile
