@@ -31,4 +31,13 @@ class InvoiceAdminForm(forms.ModelForm):
         ]
 
     def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+        instance = kwargs.get("instance", None)
+        initial = kwargs.pop("initial", dict())
+        if instance is not None:
+            initial.update({"customer": instance.customer})
+        return super().__init__(initial=initial, *args, **kwargs)
+
+    def save(self, commit=True):
+        self.instance.customer = self.cleaned_data["customer"]
+        instance = super().save(commit)
+        return instance
