@@ -31,6 +31,7 @@ from simpel.simpel_core.models.models import BaseSetting
 from simpel.simpel_core.models.registries import register_setting
 from simpel.simpel_core.models.templates import PathModelTemplate
 from simpel.simpel_products.models import Group, Product
+from simpel.utils import reverse
 
 from .settings import simpel_invoices_settings as invoices_settings
 
@@ -280,6 +281,8 @@ class Invoice(
         verbose_name=_("Grand Total"),
     )
 
+    allow_comments = models.BooleanField(default=True)
+
     doc_prefix = "INV"
 
     class Meta:
@@ -372,12 +375,11 @@ class Invoice(
 
     @cached_property
     def admin_url(self):
-        try:
-            from django_hosts.resolvers import reverse
+        view_name = "admin:simpel_invoices_invoice_inspect"
+        return reverse(view_name, args=(self.id,), host="admin")
 
-            return reverse("admin:simpel_invoices_invoice_inspect", args=(self.id,), host="admin")
-        except Exception:
-            return reverse("admin:simpel_invoices_invoice_inspect", args=(self.id,))
+    def get_absolute_url(self):
+        return reverse(invoices_settings.INVOICE_ABSOLUTE_URL_NAME, kwargs={"pk": self.pk})
 
     def get_total(self):
         aggregate = self.items.all().aggregate
