@@ -1,3 +1,4 @@
+from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ImproperlyConfigured
 from django_hookup import core as hookup
 
@@ -20,8 +21,24 @@ def get_product_models():
             else:
                 pass
         else:
-            raise ImproperlyConfigured(
-                "Hook REGISTER_PRODUCT_MODEL should return Product subclass"
-            )
+            raise ImproperlyConfigured("Hook REGISTER_PRODUCT_MODEL should return Product subclass")
 
     return child_models
+
+
+def get_product_states():
+    models = get_product_models()
+    states = dict()
+    for model in models:
+        model_type = ContentType.objects.get_for_model(model)
+        queryset = Product.objects.filter(polymorphic_ctype=model_type.id)
+        count = queryset.count()
+        model_key = "%s.%s" % (model_type.app_label, model_type.model)
+        states.update(
+            {
+                model_key: {
+                    "count": count,
+                },
+            }
+        )
+    return states
