@@ -1,10 +1,11 @@
 from django.core.exceptions import ValidationError
 from django.core.validators import MaxValueValidator, MinValueValidator
 from django.db import models
+from django.urls import reverse
 from django.utils import timezone
 from django.utils.functional import cached_property
 from django.utils.translation import gettext_lazy as _
-
+from filer.fields.image import FilerImageField
 from mptt.models import MPTTModel, TreeForeignKey
 from polymorphic.models import PolymorphicModel
 from taggit.managers import TaggableManager
@@ -178,6 +179,12 @@ class Product(NumeratorMixin, PolymorphicModel):
         editable=False,
         verbose_name=_("Unique ID"),
     )
+    thumbnail = FilerImageField(
+        null=True,
+        blank=True,
+        on_delete=models.SET_NULL,
+        related_name="product_thumbnails",
+    )
     parent = models.ForeignKey(
         "self",
         related_name="variants",
@@ -316,9 +323,15 @@ class Product(NumeratorMixin, PolymorphicModel):
         verbose_name=_("Can be Purchased"),
     )
 
+    allow_comments = models.BooleanField(
+        default=True,
+        help_text=_("Enable comments"),
+    )
+
     icon = "package-variant-closed"
     doc_prefix = "PRD"
     has_parameters = False
+
     objects = ProductManager()
 
     class Meta:
@@ -371,7 +384,10 @@ class Product(NumeratorMixin, PolymorphicModel):
         return summary or 0
 
     def __str__(self):
-        return self.name
+        if self.parent is not None:
+            return "%s - %s" % (self.parent.name, self.name)
+        else:
+            return self.name
 
     def get_variants(self):
         return self.specific.variants.all()
@@ -379,6 +395,11 @@ class Product(NumeratorMixin, PolymorphicModel):
     def get_admin_url(self):
         return self.get_absolute_url()
 
+    def get_absolute_url(self):
+        from .settings import simpel_products_settings as products_settings
+
+        return reverse(products_settings.PRODUCT_ABSOLUTE_URL_NAME, kwargs={"pk": self.pk})
+
     def natural_key(self):
         keys = (self.inner_id,)
         return keys
