@@ -6,7 +6,6 @@ from django.contrib.contenttypes.fields import GenericForeignKey, GenericRelatio
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
 from django.forms import ValidationError
-from django.urls import reverse
 from django.utils import timezone
 from django.utils.functional import cached_property
 from django.utils.translation import gettext_lazy as _
@@ -21,6 +20,7 @@ from simpel.simpel_core.models.registries import register_setting
 from simpel.simpel_core.models.templates import PathModelTemplate
 from simpel.simpel_products.models import Group
 from simpel.simpel_sales.models import SalesOrder
+from simpel.utils import reverse
 
 from .mixins import WorkOrderActionMixin
 
