@@ -1,13 +1,13 @@
 from django.contrib import admin
-from django.forms.widgets import SelectMultiple
 from django.utils.translation import gettext_lazy as _
 from django_filters import filters
-from django_filters.filters import MultipleChoiceFilter
 from django_filters.filterset import FilterSet
 
+# TODO maybe unused
 from simpel.simpel_products.filters import get_product_child_choices
+from simpel.simpel_products.models import Group
 
-from .models import SalesOrder
+from .models import SalesOrder, SalesQuotation
 
 
 class SalesOrderFilterSet(FilterSet):
@@ -16,20 +16,48 @@ class SalesOrderFilterSet(FilterSet):
         field_name="status",
         label=_("Status"),
     )
+    group = filters.ModelMultipleChoiceFilter(
+        queryset=Group.objects.filter(
+            code__in=[
+                "KAL",
+                "LAB",
+                "LIT",
+                "LAT",
+                "PRO",
+                "LIB",
+                "KSL",
+            ]
+        )
+    )
 
     class Meta:
         model = SalesOrder
-        fields = ("status",)
+        fields = ("status", "group")
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.filters["product_type"] = MultipleChoiceFilter(
-            label=_("Product Types"),
-            field_name="contenttype_id",
-            widget=SelectMultiple(),
-            choices=get_product_child_choices(key_name="id"),
-            help_text=_("Press CTRL + Click to select the choices."),
+
+class SalesQuotationFilterSet(FilterSet):
+    status = filters.MultipleChoiceFilter(
+        choices=SalesQuotation.STATUS_CHOICES,
+        field_name="status",
+        label=_("Status"),
+    )
+    group = filters.ModelMultipleChoiceFilter(
+        queryset=Group.objects.filter(
+            code__in=[
+                "KAL",
+                "LAB",
+                "LIT",
+                "LAT",
+                "PRO",
+                "LIB",
+                "KSL",
+            ]
         )
+    )
+
+    class Meta:
+        model = SalesOrder
+        fields = ("status", "group")
 
 
 class OrderAdminFilterSet(admin.SimpleListFilter):
