@@ -6,11 +6,10 @@ from django.contrib.contenttypes.fields import GenericForeignKey, GenericRelatio
 from django.contrib.contenttypes.models import ContentType
 from django.core.validators import MaxValueValidator, MinValueValidator
 from django.db import models
-from django.urls import reverse
 from django.utils import timezone
 from django.utils.functional import cached_property
 from django.utils.translation import gettext_lazy as _
-
+from django_qrcodes.models import LinkedQRCode
 from polymorphic.models import PolymorphicModel
 
 from simpel.simpel_auth.models import LinkedAddress
@@ -21,7 +20,7 @@ from simpel.simpel_core.models import BaseSetting, NumeratorMixin
 from simpel.simpel_core.models.registries import register_setting
 from simpel.simpel_core.models.templates import PathModelTemplate
 from simpel.simpel_products.models import Group, Product
-from django_qrcodes.models import LinkedQRCode
+from simpel.utils import reverse
 
 from .managers import OrderItemBundleManager, OrderItemManager, OrderManager
 from .mixins import SalesOrderActionMixin, SalesQuotationActionMixin
@@ -199,6 +198,8 @@ class SalesQuotation(
         object_id_field="linked_object_id",
     )
 
+    allow_comments = models.BooleanField(default=True)
+
     doc_prefix = "SQ"
     objects = OrderManager()
 
@@ -230,11 +231,13 @@ class SalesQuotation(
 
     @cached_property
     def admin_url(self):
-        try:
-            from django_hosts.resolvers import reverse as host_reverse
-            return host_reverse("admin:simpel_sales_salesquotation_inspect", args=(self.id,), host="admin")
-        except Exception:
-            return reverse("admin:simpel_sales_salesquotation_inspect", args=(self.id,))
+        view_name = "admin:simpel_sales_salesquotation_inspect"
+        return reverse(view_name, args=(self.id,), host="admin")
+
+    def get_absolute_url(self):
+        from .settings import simpel_sales_settings as sales_settings
+
+        return reverse(sales_settings.SALESQUOTATION_ABSOLUTE_URL_NAME, kwargs={"pk": self.pk})
 
     @cached_property
     def qrcode(self):
@@ -363,6 +366,13 @@ class SalesQuotationItem(NumeratorMixin, ParanoidMixin):
         editable=False,
         verbose_name=_("Total"),
     )
+
+    deliverable_informations = GenericRelation(
+        LinkedAddress,
+        content_type_field="linked_object_type",
+        object_id_field="linked_object_id",
+    )
+
     doc_prefix = "QUI"
 
     class Meta:
@@ -383,6 +393,10 @@ class SalesQuotationItem(NumeratorMixin, ParanoidMixin):
     def opts(self):
         return self.__class__._meta
 
+    @cached_property
+    def deliverable_information(self):
+        return self.deliverable_informations.filter(address_type=LinkedAddress.DELIVERABLE).first()
+
     def get_total_bundles(self):
         return self.bundles.all().aggregate(total=models.Sum("total"))["total"] or 0
 
@@ -584,6 +598,8 @@ class SalesOrder(PolymorphicModel, NumeratorMixin, SalesOrderActionMixin, Parano
         object_id_field="linked_object_id",
     )
 
+    allow_comments = models.BooleanField(default=True)
+
     doc_prefix = "SO"
     objects = OrderManager()
 
@@ -634,11 +650,13 @@ class SalesOrder(PolymorphicModel, NumeratorMixin, SalesOrderActionMixin, Parano
 
     @cached_property
     def admin_url(self):
-        try:
-            from django_hosts.resolvers import reverse as host_reverse
-            return host_reverse("admin:simpel_sales_salesorder_inspect", args=(self.id,), host="admin")
-        except Exception:
-            return reverse("admin:simpel_sales_salesorder_inspect", args=(self.id,))
+        view_name = "admin:simpel_sales_salesorder_inspect"
+        return reverse(view_name, args=(self.id,), host="admin")
+
+    def get_absolute_url(self):
+        from .settings import simpel_sales_settings as sales_settings
+
+        return reverse(sales_settings.SALESORDER_ABSOLUTE_URL_NAME, kwargs={"pk": self.pk})
 
     @cached_property
     def action_logs(self):
@@ -692,9 +710,9 @@ class SalesOrder(PolymorphicModel, NumeratorMixin, SalesOrderActionMixin, Parano
     def downpayment(self):
         downpayment = Decimal("0.00")
         if self.payments is not None:
-            downpayment = (
-                self.payments.filter(status__in=[const.VALID, const.APPROVED]).aggregate(total=models.Sum("amount"))
-            )["total"] or Decimal("0.00")
+            downpayment = (self.payments.filter(status__in=[const.APPROVED]).aggregate(total=models.Sum("amount")))[
+                "total"
+            ] or Decimal("0.00")
         return downpayment
 
     @cached_property
@@ -978,4 +996,5 @@ class ProformaInvoice(NumeratorMixin, models.Model):
 
     @cached_property
     def admin_url(self):
-        return reverse("admin:simpel_sales_proformainvoice_inspect", args=(self.id,))
+        view_name = "admin:simpel_sales_proformainvoice_inspect"
+        return reverse(view_name, args=(self.id,), host="admin")
