@@ -7,14 +7,14 @@ from . import factories as fcs
 
 class SalesOrderTestCase(TestCase):
     def test_create_sales_order(self):
-        sales_order = fcs.SalesOrderFactory()
-        sales_order.save()
+        salesorder = fcs.SalesOrderFactory()
+        salesorder.save()
         product = products_fcs.ServiceFactory()
         product.save()
-        sales_order_item = fcs.SalesOrderItemFactory(
-            sales_order=sales_order,
+        salesorder_item = fcs.SalesOrderItemFactory(
+            salesorder=salesorder,
             product=product,
             price=product.price,
             quantity=2,
         )
-        sales_order_item.save()
+        salesorder_item.save()
